# Nash Billing Sync

## Quick Guide
Below are the steps on how to get the web app up and running

1.	Install it:
```bash
    pip install nashbillingsync
```
2.	View get started documentation:
```bash
    https://nashbillingsuite.readme.io/v1.0.0/docs
```
3.	Start Coding